Date: 01 4, 2002 11:59:15 AM

# fprintnvar

## Purpose

OBSOLETE. To fileName, print the value of the variable var in the ordth element's node.

## Syntax

fprintnvar(fileName, var, ord)

filename - type: str
var - type:
ord - type:

## Returns

## Remarks

The output file (fileName) must be set up in advance using openfile, fileout or an output statement.

## Example

## See Also

fprintgvar, fprintxvar, openfile, fileout, POST Actions